#!/bin/bash
##
## This script is a wrapper before starting the actual job.
## It will setup working and temporary directories and
## error handlers for aborting and exiting in a well-defined fashion
##

abortedByUser()
{
	sleep 5 ## wait 5 seconds for other processes to die and release files
	if [ "${JOB_DEBUG}" ]; then
		echo "Aborted by user" >> ${SGE_STDERR_PATH}
	else
		echo "Aborted by user" > ${SGE_STDERR_PATH}
	fi
	exit 137
}

## This function is executed when the script exits
cleanupOnExit()
{
	EXIT_CODE=$?
	echo "Ended: `date +'%Y-%m-%d %T'`" >> ${STATUS_FILE}
	echo "ExitCode: ${EXIT_CODE}" >> ${STATUS_FILE}
	
	## Remove temporary directory unless debugging
	cd ${WD}
	if [ -z "${JOB_DEBUG}" ] && [ -d "${TMPDIR}" ]; then
		rm -rf ${TMPDIR}
	fi
}

## Maybe delay this job for some time
sleep ${JOB_DELAY:-0}

## Register as started
echo "Started: `date +'%Y-%m-%d %T'`" >> ${STATUS_FILE}

## Add handler for cleaning up after the job has ended
trap cleanupOnExit EXIT

## Add handler for catching 'kill' signals
trap abortedByUser TERM

## For some reason when running in VirtualBox with a shared folder it may
## take some time for the 'x' flag to be set on uploaded script files
## so we may have to wait for some time until we can continue.
## If this doesn't work, then configure the job folder to be on a
## virtual drive instead
while [ ! -x ${WD}/job.sh ]
do
	echo "Sleeping for 5s since job.sh is not executable"
	sleep 5
done
echo "job.sh is executable"

## Create temporary directory and ensure that it is empty (unless debugging)
mkdir -p ${TMPDIR}
if [ -z "${JOB_DEBUG}" ]; then
	rm -rf ${TMPDIR}/*
fi

## Finally, we can now run the actual job
cd ${WD}
nice -n ${NICE:-0} ./job.sh
JOB_EXIT_CODE=$?

## Exit with the exit code from the job
## (not really needed in the current implementation since job.sh is the last cmd)
exit ${JOB_EXIT_CODE}
